@@ -3,7 +3,12 @@ from .main import (
     output_crosstab_cate_barplot,
     output_multi_binaries_with_strat,
     question_data_containers_from_dataframe,
+    heatmap_crosstab_from_df,
+)
+from .utils import (
+    item_str2dict,
+    imputate_reorder_table,
+    delete_and_create_csv,
 )
-from .utils import delete_and_create_csv
 from .variables import QuestionDataContainer, VisVariables
 from .__version__ import __version__
